<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=zh
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => '增加的段落',
	'diff_para_deplace' => '移动的段落',
	'diff_para_supprime' => '删除的段落',
	'diff_texte_ajoute' => '增加的文字',
	'diff_texte_deplace' => '移动的文字',
	'diff_texte_supprime' => '删除的文字',

	// I
	'info_historique' => '修订：',
	'info_historique_lien' => '显示修订历史',
	'info_historique_titre' => '修订跟踪',

	// V
	'version_initiale' => '原版本',
];
